CONTRIBUTING
------------

- increment the version number in `cabbage/__init__.py` file
- update `CHANGELOG.md`
- if necessary, update the “Contributors” and “Thanks also to” sections of `AUTHORS.md`.
